from bioservices.picr import PICR
import pytest

# As of Feb 2020, we cannot find picr service on EBI website anymore.
# Most probably deprecated

"""
@pytest.fixture
def picr():
    return PICR(verbose=True)




def test_getUPIForSequence(picr):
    res = picr.getUPIForSequence(picr._sequence_example,
            ["IPI", "ENSEMBL", "SWISSPROT"])
    res = picr.getUPIForSequence(picr._sequence_example, "SWISSPROT",
            taxid="9606")
    res = picr.getUPIForSequence(picr._sequence_example, "SWISSPROT",
            onlyactive=False, includeattributes=False)

def test_databases(picr):
    assert len(picr.databases) > 0

def test_MappedDB(picr):
    picr.getMappedDatabaseNames()

def test_checkDB(picr):
    picr._checkDBname("IPI")
    try:
        picr._checkDBname("dummy")
        assert False
    except:
        assert True

def test_getUPIForAccession(picr):
    picr.getUPIForAccession(picr._accession_example, ["SWISSPROT"])
    picr.getUPIForAccession(picr._accession_example, "SWISSPROT", taxid="9606")
    res = picr.getUPIForAccession(picr._accession_example, "SWISSPROT", onlyactive=False, includeattributes=False)

# Those ones do not work
def _test_getUPIForBLAST(picr):
    picr.getUPIForBLAST(picr._blastfrag_example, "SWISSPROT", taxid="9606")

def _test_getUPIForBLAST2(picr):
    picr.getUPIForBLAST(picr._blastfrag_example, ["SWISSPROT"], taxid="9606", includeattributes=False)

def _test_getUPIForBLAST3(picr):
    picr.getUPIForBLAST(picr._blastfrag_example, ["SWISSPROT"], taxid="9606", program="blastp",matrix="BLOSUM62")

"""



from bioservices import ArrayExpress
import pytest


@pytest.fixture
def array():
    return ArrayExpress(verbose=False)


def test_retrieveFiles(array):
    #res = array.retrieveFiles(keywords="cancer+breast", species="Home+Sapiens")
    res = array.queryFiles(array="A-AFFY-33")

def test_retrieveExperiments(array):
    #res = array.retrieveExperiments(keywords="cancer+breast", species="Home+Sapiens")

    #res = array.queryExperiments(array="A-AFFY-33")
    #assert len(res.getchildren())>0
    res = array.queryExperiments(array="A-AFFY-33", species="Homo Sapiens",expdesign="dose+response")
    assert len(res.getchildren())>0
    res = array.queryExperiments(array="A-AFFY-33", species="Homo Sapiens",expdesign="dosestupid")
    assert len(res.getchildren())==0
    res = array.queryExperiments(array="A-AFFY-33", species="Homo Sapiens", expdesign="dose+response", 
        sortby="releasedate", sortorder="ascending")

def test_retrieveFile(array):
    res = array.retrieveFile("E-MEXP-31", "E-MEXP-31.idf.txt")
    array.retrieveFile("E-MEXP-31", "E-MEXP-31.idf.txt", save=True) 
    import os
    os.remove("E-MEXP-31.idf.txt")

    try:
        res == array.retrieveFile("E-MEXP-31", "E-MEXP-31.idf.txtdddd")
        assert False
    except:
        pass

def test_format(array):
    array.format = "json"
    array.format = "xml"
    try:
        array.format = "dummy"
        assert False
    except:
        assert True

def test_retrieveExperiment(array):
    array.retrieveExperiment("E-MEXP-31")

def test_extra1(array):
    # works. just takes 15 seconds so let us skip it.
    res = array.queryFiles(keywords="cancer+breast", wholewords=True)
def test_extra2(array):
    res = array.queryFiles(keywords="cancer+breast", wholewords=True, gxa="true")
def test_extra3(array):
    res = array.queryFiles(keywords="cancer+breast", wholewords=True, directsub="false")


def test_extra4():
    ae = ArrayExpress(verbose=False)
    ae.TIMEOUT = 60
    try:
        res = ae.queryAE(keywords="pneumonia", species='homo+sapiens')
    except:
        pass



from bioservices.muscle import MUSCLE
from bioservices import uniprot
import pytest
import os

skiptravis = pytest.mark.skipif( "TRAVIS_PYTHON_VERSION" in os.environ,
     reason="too long On travis ")

@skiptravis
def test_muscle():
    m = MUSCLE(verbose=False)
    m.parameters
    m.getParametersDetails("format")

    u = uniprot.UniProt(verbose=False)
    f1 = u.get_fasta("P18812")
    f2 = u.get_fasta("P18813")

    jobid = m.run(frmt="fasta", sequence=f1+f2, email="cokelaer@ebi.ac.uk")
    m.getStatus(jobid)
    m.wait(jobid)

    m.getResultTypes(jobid)
    m.getResult(jobid, 'phylotree')




from bioservices import Reactome, ReactomeOld
import pytest
from easydev import TempFile
import os
skiptravis = pytest.mark.skipif( "TRAVIS_PYTHON_VERSION" in os.environ,
     reason="On travis")


@pytest.fixture
def reactome():
    return Reactome(verbose=True)


def test_data_discover(reactome):
    res = reactome.data_discover("R-HSA-446203")
    assert "name" in res


def test_data_diseases(reactome):
    res = reactome.data_diseases()
    assert len(res)


def test_data_diseases_doid(reactome):
    res = reactome.data_diseases_doid()
    assert len(res)


@skiptravis
def test_exporter_diagram(reactome):
    res = reactome.exporter_diagram(109581, ext="png")
    res = reactome.exporter_diagram(109581, ext="jpg")
    res = reactome.exporter_diagram(109581, ext="jpg", quality=1)
    res = reactome.exporter_diagram(109581, ext="jpg", quality=1,
                                    diagramProfile="Standard")

    with TempFile(suffix=".png") as fout:
        res = reactome.exporter_diagram(109581, ext="png", filename=fout.name)


def test_data_complex_subunits(reactome):
    assert len(reactome.data_complex_subunits("R-HSA-5674003"))


def test_data_complexes(reactome):
    assert len(reactome.data_complexes("UniProt", "P43403"))
    assert reactome.data_complexes("UniProt", "P434") == 404


def test_data_entity_componentOf(reactome):
    assert len(reactome.data_entity_componentOf("R-HSA-199420"))


def test_data_entity_otherForms(reactome):
    assert len(reactome.data_entity_otherForms("R-HSA-199420"))


def test_data_event_ancestors(reactome):
    assert len(reactome.data_event_ancestors("R-HSA-5673001"))


def test_data_events_hierarchy(reactome):
    assert len(reactome.data_eventsHierarchy(9606))


def test_exporter_sbml(reactome):
    assert len(reactome.exporter_sbml("R-HSA-68616"))


def test_data_pathway_containedEvents(reactome):
    res = reactome.data_pathway_containedEvents("R-HSA-5673001")
    assert len(res)


def test_data_pathway_containedEvents_by_attribute(reactome):
    res = reactome.data_pathway_containedEvents_by_attribute("R-HSA-5673001", "stId")
    assert len(res)


def test_data_pathways_low_diagram_entity(reactome):
    res = reactome.data_pathways_low_diagram_entity("R-HSA-199420")
    assert len(res)


def test_data_pathways_low_diagram_entity_allForms(reactome):
    res = reactome.data_pathways_low_diagram_entity_allForms("R-HSA-199420")
    assert len(res)


def test_data_pathways_low_diagram_identifier_allForms(reactome):
    res = reactome.data_pathways_low_diagram_identifier_allForms("PTEN")
    assert len(res)


def test_data_pathways_low_entity(reactome):
    res = reactome.data_pathways_low_entity("R-HSA-199420")
    assert len(res)


def test_data_pathways_low_entity_allForms(reactome):
    res = reactome.data_pathways_low_entity_allForms("R-HSA-199420")
    assert len(res)


def test_data_pathways_top(reactome):
    res = reactome.data_pathways_top(9606)
    assert len(res)


def test_references(reactome):
    res = reactome.references(15377)
    assert len(res)


def test_search_facet(reactome):
    res = reactome.search_facet()
    assert len(res)


def test_search_facet_query(reactome):
    res = reactome.search_facet_query("R-HSA-199420")
    assert len(res)


def test_search_query(reactome):
    res = reactome.search_query("R-HSA-199420")
    assert len(res)


def test_search_spellcheck(reactome):
    res = reactome.search_spellcheck("appostosis")
    assert len(res)


def test_search_suggest(reactome):
    res = reactome.search_spellcheck("apost")
    assert len(res)


def test_data_species_all(reactome):
    res = reactome.data_species_all()
    assert len(res)


def test_data_species_main(reactome):
    res = reactome.data_species_main()
    assert len(res)



# obsolet
def __test_species():
    r = ReactomeOld(verbose=True)
    assert len(r.get_species()) > 10
    res = r.query_by_ids("Pathway", 'TP53')
    assert len(res) >= 1




#!/usr/bin/python
# -*- coding: latin-1 -*-
#
#  This file is part of bioservices software
#
#  Copyright (c) 2013-2015 - EBI-EMBL
#  Copyright (c) 2016-2017 - Institut Pasteur
#
#  File author(s): thomas cokelaer
#
#  Distributed under the GPLv3 License.
#  See accompanying file LICENSE.txt or copy at
#      http://www.gnu.org/licenses/gpl-3.0.html
#
#  website: https://github.com/cokelaer/bioservices
#  documentation: http://packages.python.org/bioservices
#
##############################################################################
"""This module provides a class :class:`~Seqret` to access to Seqret WS.


.. topic:: What is Seqret ?

    :URL: http://www.ebi.ac.uk/Tools/services/rest/seqret/
    :Service:
    :Citations: http://www.ncbi.nlm.nih.gov/pubmed/18428689

    .. highlights::

        EMBOSS seqret reads and converts biosequences between a selection of common
        biological sequence formats, including EMBL, GenBank and fasta sequence
        formats.

        Seqret homepage -- Sep 2017


"""
import copy
from bioservices.services import REST


__all__ = ["Seqret"]



class Seqret(REST):
    """Interface to the `Seqret <http://www.ebi.ac.uk/readseq>`_ service

    ::

        >>> from bioservices import *
        >>> s = Seqret()

    The ReadSeq service was replaced by the Seqret services (2015).

    .. versionchanged:: 0.15

    """
    _url = "https://www.ebi.ac.uk/Tools/services/rest/emboss_seqret"
    def __init__(self, verbose=True):
        """.. rubric:: Constructor

        :param bool verbose:

        """
        super(Seqret, self).__init__(name="seqret", url=Seqret._url, verbose=verbose)
        self._parameters = None

    def _get_parameter(self):
        if self._parameters is None:
            self._parameters = self._get_parameters()
        return self._parameters
    parameters = property(_get_parameter, doc="Get list of parameter names")

    def _get_parameters(self):
        """Get a list of the parameter names.

        :returns: a list of strings giving the names of the parameters.

        """
        parameters = self.http_get("parameters", frmt="xml")
        res = self.easyXML(parameters)
        parameters = [x.text for x in res.findAll("id")]
        return parameters

    def get_parameter_details(self, parameter):
        """Get details of a specific parameter.

        :param str parameter: identifier/name of the parameter to fetch details of.
        :return: a data structure describing the parameter and its values.

        ::

            rs = ReadSeq()
            print(rs.get_parameter_details("stype"))

        """
        parameters = self.http_get("parameterdetails/{}".format(parameter), frmt="xml")
        res = self.easyXML(parameters)

        results = []
        for value in res.findAll('values')[0].findAll("value"):
            items = value.findAll()
            if len(items):
                results.append({
                    "text": items[0].text,
                    "value": items[1].text,
                    "defaultvalue": items[2].text})

        return results

    def run(self, email, title, **kargs):
        """Submit a job to the service.

        :param str email: user e-mail address.
        :param str title: job title.
        :param params: parameters for the tool as returned by :meth:`get_parameter_details`.
        :return: string containing the job identifier (jobId).

        Deprecated (olf readseq service)::

            Format Name     Value
            Auto-detected   0
            EMBL            4
            GenBank         2
            Fasta(Pearson)  8
            Clustal/ALN     22
            ACEDB           25
            BLAST           20
            DNAStrider      6
            FlatFeat/FFF    23
            GCG             5
            GFF             24
            IG/Stanford     1
            MSF             15
            NBRF            3
            PAUP/NEXUS      17
            Phylip(Phylip4)     12
            Phylip3.2       11
            PIR/CODATA      14
            Plain/Raw       13
            SCF             21
            XML             19

        As output, you also have

        Pretty 18

        ::

            s = readseq.Seqret()
            jobid = s.run("cokelaer@test.co.uk", "test", sequence=fasta, inputformat=8,
                outputformat=2)
            genbank = s.get_result(s._jobid)


        """
        for k in kargs.keys():
            self.devtools.check_param_in_list(k, self.parameters)

        assert "sequence" in kargs.keys()
        params = {"email":email, "title":title}

        for k in ['stype', 'inputformat','outputformat', "feature", "firstonly",
                  "reverse", 'outputcase', 'seqrange']:
            if k in kargs.keys():
                value = kargs.get(k)

                details = self.get_parameter_details(k)
                valid_values = [x['value'] for x in details]

                self.devtools.check_param_in_list(str(value), valid_values)
                params[k] = value
        #r = requests.post(url + "/run?", data={"sequence":fasta, "stype": "protein",
        #"inputformat":"raw", "outputformat":"fasta", "email":"thomas.cokelaer@pasteur.fr",
        #"title":"test"})

        params['sequence'] = kargs['sequence']

        jobid = self.http_post("run", frmt="txt", data=params)
        self._jobid = jobid
        return jobid

    def get_status(self, jobid=None):
        """Get the status of a submitted job.

        :param str jobid: job identifier.
        :return: string containing the status.

        The values for the status are:

        - RUNNING: the job is currently being processed.
        - FINISHED: job has finished, and the results can then be retrieved.
        - ERROR: an error occurred attempting to get the job status.
        - FAILURE: the job failed.
        - NOT_FOUND: the job cannot be found.

        """
        res = self.http_get("status/{}".format(jobid))
        return res.content.decode()

    def get_result_types(self, jobid):
        """Get the available result types for a finished job.

        :param str jobid: job identifier.
        :return: a list of wsResultType data structures describing the available result types.
        """
        res = self.http_get("resulttypes/{}".format(jobid))

        res = self.easyXML(res.content.decode())
        this = res.findAll("types")[0].findAll("type")[0].findAll('identifier')
        return this[0].text

    def get_result(self, jobid, parameters=None):
        """Get the result of a job of the specified type.

        :param str jobid: job identifier.
        :param parameters: optional list of wsRawOutputParameter used to
            provide additional parameters for derived result types.
        :return: the result data for the specified type, base64 encoded.
            Depending on the SOAP library and programming language used the
            result may be returned in decoded form. For some result types
            (e.g. images) this will be binary data rather than a text string.
        """
        if self.get_status(jobid) != 'FINISHED':
            self.logging.warning("Your job is not finished yet. Try again later.")
            return

        result_types = self.get_result_types(jobid)

        res = self.http_get("result/{}/{}".format(jobid, result_types))
        res = res.content.decode()

        try:
            import base64
            res = base64.b64decode(res).decode()
        except:
            pass
        return res




from bioservices.eutils import EUtilsParser, EUtils
import pytest

@pytest.fixture
def eutils():
    return EUtils(verbose=False)


def test_taxonomy(eutils):
    ret = eutils.taxonomy_summary("9606")
    assert ret['9606']['taxid'] == 9606


def test_snp(eutils):
    eutils.snp_summary("123")


def test_databases(eutils):
    assert "proteinclusters" in eutils.databases


def test_summary(eutils):
    ret = eutils.ESummary("taxonomy", "9606,9913")
    assert ret['9606']['taxid'] == 9606
    assert ret['9913']['taxid'] == 9913

    # test another database 
    ret = eutils.ESummary("structure", "10000")
    assert ret['10000']['pdbacc'] == '1CA4'


def test_espell(eutils):
    ret = eutils.ESpell(db="omim", term="aasthma+OR+alergy")
    ret = ret.eSpellResult
    print(ret.Query)
    assert ret.Query == 'aasthma OR alergy'
    assert ret.CorrectedQuery == 'asthma or allergy'


def test_esearch(eutils):
    ret = eutils.ESearch('protein', 'human', RetMax=5)


def test_elink(eutils):
    ret = eutils.ELink(db="pubmed", dbfrom="pubmed", id="20210808",
                       cmd="neighbor_score")

    ret = eutils.ELink(db="pubmed", id="24064416")

    # assert len(ret.LinkSet[0].LinkSetDb[0].Link) > 10

    eutils.ELink(dbfrom="nucleotide", id="48819,7140345", db="protein")

def test_einfo(eutils):
    # Use XML
    dbinfo = eutils.EInfo("gtr", retmode='xml')
    dbinfo = eutils.parse_xml(dbinfo, 'EUtilsParser').eInfoResult
    dbinfo = dbinfo.DbInfo
    assert dbinfo.DbName == 'gtr'
    assert dbinfo.MenuName == 'GTR'
    assert dbinfo.Description == 'GTR Database'
    assert dbinfo.FieldList.Field[0].Name == 'ALL'

    # use JSON
    ret = eutils.EInfo("taxonomy")[0]
    ret['count']

    alldbs = eutils.EInfo()
    for db in ['pubmed', 'genome', 'dbvar', 'gene']:
        assert db in alldbs
    assert len(alldbs) > 40  # 52 Aug 2014 but let us be on the safe side


def test_einfo_pubmed(eutils):
    ret = eutils.EInfo('pubmed')[0]
    assert ret['dbname'] == 'pubmed'
    assert ret['menuname'] == 'PubMed'
    assert ret['description'] == 'PubMed bibliographic record'
    assert int(ret['count']) > 17905967
    assert ret['lastupdate']
    assert len(ret['fieldlist']) >= 40
    assert ret['fieldlist'][0]['name'] == 'ALL'
    assert ret['fieldlist'][0]['fullname'], 'All Fields'


def test_gquery(eutils):
    ret = eutils.EGQuery("asthma")
    [(x.DbName, x.Count) for x in ret.eGQueryResult.ResultItem
     if x.Count != '0']


def test_efetch(eutils):
    ret = eutils.EFetch("omim", "269840")
    ret1 = eutils.EFetch("protein", "34577063",
                         retmode="text", rettype="fasta", stand=1)
    ret2 = eutils.EFetch("protein", "34577063",
                         retmode="text", rettype="fasta", stand=2)
    eutils.EFetch("protein", "34577063",
                  retmode="text", rettype="fasta", strand=2,
                  seq_start=10, seq_stop=20)

    ret = eutils.EFetch('pubmed', '12091962,9997',
                        retmode='xml', rettype='abstract')
    # sequences
    res1 = eutils.EFetch("protein", "352, 234",
                         retmode="text", rettype="fasta")
    res2 = eutils.EFetch("protein", ["352", "234"],
                         retmode="text", rettype="fasta")
    res3 = eutils.EFetch("protein", [352, 234],
                         retmode="text", rettype="fasta")

    assert res1 == res2
    assert res2 == res3
    assert res1 == res3

def test_efetch_gene(eutils):
    res = eutils.EFetch('gene', 4747, retmode="text")
    assert b'neurofilament' in res
    res = eutils.EFetch('gene', 4747, retmode="xml")


def test_epost(eutils):
    ret = eutils.EPost("pubmed", "20210808")
    assert ret['QueryKey']
    assert ret['WebEnv']
    print(ret)


def test_check_db(eutils):
    try:
        eutils._check_db('dummy')
        assert False
    except:
        assert True


def test_check_retmode(eutils):
    try:
        eutils._check_retmode('dummy')
        assert False
    except:
        assert True


def test_check_ids(eutils):
    assert eutils._check_ids(None) == None

    eutils._check_ids(",".join([str(x) for x in range(199)]))
    try:
        eutils._check_ids(",".join([str(x) for x in range(201)]))
        assert False
    except:
        assert True


def test_efetch_xml(eutils):
    xml = eutils.EFetch(db="nuccore",id="AP013055", rettype="docsum",
        retmode="xml")
    res = eutils.parse_xml(xml, "EUtilsParser")
    assert res['eSummaryResult']['DocSum']['Id'] == '578887486'
    assert res['eSummaryResult']['DocSum']['Item'][0] == 'AP013055'








from bioservices import PDB


pdb = PDB(verbose=False)



def test_pdb():
    res = pdb.get_file("1FBV", "pdb")
    res = pdb.get_file("1FBV", "xml", compression=True)
    res = pdb.get_file("1FBV", "cif")
    ids = pdb.get_current_ids()

def test_ligands():
    '4HHB' in pdb.get_ligands("4HHB")

# FIXME
def _test_get_xml_query():
    query = """<?xml version="1.0" encoding="UTF-8"?>
<orgPdbQuery>
<version>B0907</version>
<queryType>org.pdb.query.simple.ExpTypeQuery</queryType>
<description>Experimental Method Search : Experimental Method=SOLID-STATE NMR</description>
<mvStructure.expMethod.value>SOLID-STATE NMR</mvStructure.expMethod.value>
</orgPdbQuery>
"""
    res = pdb.get_xml_query(query)
    assert len(res.split("\n"))>10






from bioservices.dbfetch import DBFetch
import pytest

@pytest.fixture
def dbfetch():
    return DBFetch(verbose=False)


def test_getSupportedDBs(dbfetch):
    res = dbfetch.supported_databases
    res = dbfetch.supported_databases
    assert len(res) >10

def test_getSupportedFormats(dbfetch):
    res = dbfetch.get_database_formats("uniprotkb")
    assert "fasta" in res

def test_getSupportedStyles(dbfetch):
    res = dbfetch.get_database_format_styles("uniprotkb", "fasta")
    assert "raw" in res


def test_fetchData(dbfetch):
    res = dbfetch.fetch(style="raw", db="uniprotkb", format="fasta", query="zap70_human")

def test_getDatabaseInfo(dbfetch):
    res = dbfetch.get_database_info("uniprotkb")
    assert res['name'] == 'uniprotkb'

def test_getDatabaseInfoList(dbfetch):
    assert len(dbfetch.get_all_database_info())>10

def test_wrong_db(dbfetch):
    try:
        dbfetch.fetch(db="niprot", query="P43403")
        assert False
    except:
        assert True



from bioservices.uniprot import UniProt
import pytest

@pytest.fixture
def uniprot():
    u = UniProt(verbose=False, cache=False)
    u.logging.level = "ERROR"
    return u


def test_mapping(uniprot):
    res = uniprot.mapping(fr="ACC+ID", to="KEGG_ID", query='P43403')
    assert res['P43403'] == ['hsa:7535']
    try:
        res = uniprot.mapping(fr="AC", to="KEID", query='P434')
        assert False
    except:
        assert True


def test_retrieve(uniprot):
    uniprot.retrieve("P09958", frmt="rdf")
    uniprot.retrieve("P09958", frmt="xml")
    uniprot.retrieve("P09958", frmt="txt")
    uniprot.retrieve("P09958", frmt="fasta")
    uniprot.retrieve("P09958", frmt="gff")
    try:
        uniprot.retrieve("P09958", frmt="dummy")
        assert False
    except:
        assert True

def test_search(uniprot):
    uniprot.search('zap70+AND+organism:9606', frmt='list')
    uniprot.search("zap70+and+taxonomy:9606", frmt="tab", limit=3,
                columns="entry name,length,id, genes, genes(PREFERRED), interpro, interactor")
    uniprot.search("zap70+and+taxonomy:9606", frmt="tab", limit=3,
                columns="entry name, go(biological process), comment(FUNCTION), comment(DOMAIN), lineage(all)")
    uniprot.search("ZAP70_HUMAN", frmt="tab", columns="sequence", limit=1)
    uniprot.quick_search("ZAP70")

def test_uniref(uniprot):
    df = uniprot.uniref("member:Q03063")
    df.Size

def test_get_df(uniprot):
    df = uniprot.get_df(["P43403"])

def test_fasta(uniprot):
    "Q9Y617" in uniprot.get_fasta(["Q9Y617-1"])
    "Q9Y617" not in uniprot.get_fasta_sequence(["Q9Y617-1"])



from bioservices import BioDBNet
import pytest


@pytest.fixture
def biodbnet():
    return BioDBNet(verbose=False)


def test_db2db(biodbnet):
    df = biodbnet.db2db("UniProt Accession", "Gene ID", "P43403")
    assert df.loc['P43403'].values[0] == "7535"

def test_dbfind(biodbnet):        
    df = biodbnet.dbFind("Gene ID", ["ZMYM6_HUMAN", "NP_710159", "ENSP00000305919"])
    assert len(df["Gene ID"]) == 3

def test_Ortho(biodbnet):
    df = biodbnet.dbOrtho("Gene Symbol", "Gene ID", ["MYC", "MTOR", "A1BG"],
                       input_taxon=9606, output_taxon=10090)
    df.loc['MYC'].values[0] == "17869"


# SLOW FIXME
def _test_dbreport(biodbnet):
    biodbnet.dbReport("UniProt Accession", "P43403")

def test_dbwalk(biodbnet):
    biodbnet.dbWalk('Ensembl Gene ID->Gene ID->Homolog - Mouse Gene ID->Ensembl Gene ID', 
        "ENSG00000121410", 9606)

def test_extra(biodbnet):
    biodbnet.getDirectOutputsForInput("Gene Symbol")
    biodbnet.getDirectOutputsForInput("genesymbol")
    biodbnet.getInputs()
    biodbnet.getOutputsForInput("Uniprot Accession")



from bioservices.panther import Panther


p = Panther()

def test_panther_supported_genomes():
    p.get_supported_genomes()
    p.get_supported_genomes(type="chrLoc")

def test_pathways():
    p.get_pathways()


def test_mapping():


    res = p.get_mapping("zap70,erk,xxxxxx", 9606)
    assert len(res["mapped"]) == 2
    assert res["unmapped"] == ['xxxxxx']

    res = p.get_mapping("zap70,xxxxxx,yyyyyy", 9606)
    assert len(res["mapped"]) == 1
    assert res["unmapped"] == ['xxxxxx', 'yyyyyy']


def test_enrich():
    res = p.get_enrichment("zap70,mek1,erk", 9606, "ANNOT_TYPE_ID_PANTHER_PATHWAY", 
        correction="FDR",enrichment_test="Fisher")
    enrich = [x for x in res['result'] if x['pValue']<0.05 ]
    assert len(enrich) > 0

def test_math_ortholog():

    res = p.get_ortholog("zap70,xxx,yyy", 9606)
    assert len(res['unmapped']) == 2
    res = p.get_ortholog("zap70,xxx", 9606)
    assert len(res['unmapped']) == 1
    res = p.get_ortholog("zap70", 9606) 
    assert len(res['unmapped']) == 0
    assert len(res['mapped'])


def test_homolog_position():
    res = p.get_homolog_position("zap70", 9606, 1)
    res = p.get_homolog_position("xxx", 9606, 1)
    assert res['unmapped']

def test_supported_families():
    res = p.get_supported_families()
    res = p.get_supported_families(progress=False)
    try:
        res = p.get_supported_families(progress=False, N=2000)
        assert False
    except:
        assert True

def test_get_family_ortholog():
    res = p.get_family_ortholog("PTHR10000")
    assert len(res)

def test_get_family_msa():
    res = p.get_family_msa("PTHR10000")
    assert len(res)

def test_get_tree_info():
    res = p.get_tree_info("PTHR10000")




from bioservices import BioModels
import pytest
import os

#pytestmark = pytest.mark.skipif( "TRAVIS_PYTHON_VERSION" in os.environ,
#     reason="On travis")


modelId = 'BIOMD0000000256'
uniprotId = 'P10113'
pubId = '18308339'
GOId = 'GO:0001756'
reacID = "REACT_1590"
personName = "LeNovere"

@pytest.fixture
def biomodels():
    return BioModels(verbose=False)


def test_size(biomodels):
    L1 = len(biomodels.getAllCuratedModelsId())
    L2 = len(biomodels.getAllNonCuratedModelsId())
    L = len(biomodels)
    assert L == L1+L2

def test_getAllModelsId(biomodels):
    assert len(biomodels.getAllModelsId()) > 800

def test_getAllCuratedModelsId(biomodels):
    assert len(biomodels.getAllCuratedModelsId()) > 100

def test_getAllNonCuratedModelsId(biomodels):
    assert len(biomodels.getAllNonCuratedModelsId()) > 100

def test_getModelById(biomodels):
    biomodels.getModelById('MODEL1006230101')

def test_getModelSBMLById(biomodels):
    biomodels.getModelSBMLById(modelId)
    biomodels.getModelSBMLById('MODEL1006230101')

def test_getAuthorsByModelId(biomodels):
    res = biomodels.getAuthorsByModelId(modelId)
    assert res == ['Rehm M', 'Huber HJ', 'Dussmann H', 'Prehn JH']

def test_getDateLastModifByModelId(biomodels):
    res = biomodels.getDateLastModifByModelId(modelId)
    # This changes with time so no need to check 
    #assert res == '2012-05-16T14:44:17+00:00'

def test_getEncodersByModelId(biomodels):
    res = biomodels.getEncodersByModelId("BIOMD0000000256")
    assert res == ['Lukas Endler']

def test_getLastModifiedDateByModelId(biomodels):
    res = biomodels.getLastModifiedDateByModelId("BIOMD0000000256")
    # This changes with time so no need to check 
    #assert res == '2012-05-16T14:44:17+00:00'

def test_getModelNameById(biomodels):
    res = biomodels.getModelNameById("BIOMD0000000256")
    assert res == 'Rehm2006_Caspase'

    try:
        biomodels.getModelNameById("dummy")
        assert False
    except:
        assert True

def test_getModelsIdByChEBI(biomodels):
    res = biomodels.getModelsIdByChEBI('CHEBI:4978')
    res == ['BIOMD0000000217', 'BIOMD0000000404']

def test_getModelsIdByChEBIId(biomodels):
    res = biomodels.getModelsIdByChEBIId('CHEBI:4978')
    assert res == ['BIOMD0000000404']

def test_getSimpleModelsByChEBIIds(biomodels):
    biomodels.getSimpleModelsByChEBIIds('CHEBI:4978')

# FIXME
def _test_getSimpleModelsRelatedWithChEBI(biomodels):
    res = biomodels.getSimpleModelsRelatedWithChEBI()
    from bioservices import xmltools
    res = xmltools.easyXML(res.encode('utf-8'))
    modelIDs = set([x.findall('modelId')[0].text for x in res.getchildren()])
    assert len(modelIDs) > 1

def test_getPublicationByModelId(biomodels):
    res = biomodels.getPublicationByModelId("BIOMD0000000256")
    assert res == '16932741'

def test_getSimpleModelByIds(biomodels):
    biomodels.getSimpleModelsByIds(modelId)

def test_getModelsIdByPerson(biomodels):
    biomodels.getModelsIdByPerson(personName)

# FIXME
def _test_getSimpleModelsByReactomeIds(biomodels):
    return biomodels.getSimpleModelsByReactomeIds(reacID)

def test_getModelsIdByUniprotId(biomodels):
    return biomodels.getModelsIdByUniprotId(uniprotId)

def test_getModelsIdByUniprotIds(biomodels):
    biomodels.getModelsIdByUniprotIds(["P10113", "P10415"])

def test_getModelsIdByName(biomodels):
    return biomodels.getModelsIdByName('2009')

def test_getModelsIdByPublication(biomodels):
    res = biomodels.getModelsIdByPublication(pubId)
    assert res == ['BIOMD0000000201']

def test_getModelsIdByGO(biomodels):
    return biomodels.getModelsIdByGO(GOId)

def test_getModelsIdByTaxonomy(biomodels):
    return biomodels.getModelsIdByTaxonomy("EGF")

def test_getModelsIdByTaxonomyId(biomodels, taxonomyId='9606'):
    return biomodels.getModelsIdByTaxonomyId(taxonomyId)

def test_getSubModelSBML(biomodels):
    biomodels.getSubModelSBML("BIOMD0000000242", "cyclinEdegradation_1")

def test_getModelsIdByGOId(biomodels):
    biomodels.getModelsIdByGOId(GOId)

def test_extra_getChEBIIds(biomodels):
    biomodels.extra_getChEBIIds(99, 101)
    try:
        biomodels.extra_getChEBIIds(1000, 101)
        assert False
    except:
        assert True

# FIXME
def _test_extra_getReactomeIds(biomodels):
    biomodels.extra_getReactomeIds(99, 101)  # just to cross the 100 Ids
    biomodels.extra_getReactomeIds(89, 90)  # just to get one output REACT_89
    try:
        biomodels.extra_getReactomeIds(1000, 101)
        assert False
    except:
        assert True

# FIXME
def _test_extra_getUniprotIds(biomodels):
    biomodels.extra_getUniprotIds(11099, 11101)
    biomodels.extra_getUniprotIds(10113, 10114)

    try:
        biomodels.extra_getUniprotIds(1000, 101)
        assert False
    except ValueError:
        assert True

def test_getModelsIdByUniprot(biomodels):
    biomodels.getModelsIdByUniprot("P10113")
